@@ -1,3 +1,5 @@
+"""This module provides queryset methods for django template."""
+
 from django import template
 
 register = template.Library()
@@ -29,6 +31,6 @@ def dead(queryset):
 
 @register.filter
 def alive(qureyset):
-    if hasattr(qureyset, 'alive') and callable(qureyset, 'alive'):
+    if hasattr(qureyset, 'alive') and callable(qureyset.alive):
         return qureyset.alive()
     return qureyset
